JSON schemas
============

The following JSON schemas describe the format of the payloads ``iqm-client`` sends to the IQM server.

.. |link-pre| raw:: html

    <a href="run_request_schema_v

.. |link-post| raw:: html

    .json">Circuit execution request</a>

* |link-pre|\ |version|\ |link-post| sent to the computation control service.
